@@ -263,10 +263,18 @@ class FlexibilitySimulator(mosaik_api.Simulator):
                     for schedule in src_ids.values():
                         if schedule is not None:
                             if not isinstance(schedule, pd.DataFrame):
-                                schedule = pd.read_json(schedule).tz_localize(
-                                    "UTC"
-                                )
-                            self.models[eid].update_schedule(schedule)
+                                try:
+                                    schedule = pd.read_json(
+                                        schedule
+                                    ).tz_localize("UTC")
+                                except ValueError:
+                                    print(
+                                        "FlexMosaik: Failed to load: "
+                                        f"{schedule} (type={type(schedule)})"
+                                    )
+                                    continue
+                            if not schedule.empty:
+                                self.models[eid].update_schedule(schedule)
                     continue
 
                 elif attr == "local_time":
