@@ -281,19 +281,21 @@ class PysimmodsModule(UpgradeModule):
                         grid_entity_key,
                         e,
                     )
-                except KeyError:
+                except KeyError as e:
                     LOG.warning(
-                        "Entity missing for %s: %s or for grid: %s.",
+                        "Entity missing for %s: %s or for grid: %s (%s).",
                         model,
                         model_key,
                         grid_entity_key,
+                        e,
                     )
-                except ValueError:
+                except ValueError as e:
                     LOG.warning(
-                        "Entity missing for %s: %s or for grid: %s.",
+                        "Entity missing for %s: %s or for grid: %s (%s).",
                         model,
                         model_key,
                         grid_entity_key,
+                        e,
                     )
                 model_ctrs[model] += 1
 
@@ -439,12 +441,12 @@ class PysimmodsModule(UpgradeModule):
 
     def get_sensors(self):
         for sensor in self.sensors:
-            self.scenario["sensors"].append(sensor)
+            self.scenario.sensors.append(sensor)
             LOG.debug("Created sensor entry %s.", sensor)
 
     def get_actuators(self):
         for actuator in self.actuators:
-            self.scenario["actuators"].append(actuator)
+            self.scenario.actuators.append(actuator)
             LOG.debug("Created actuator entry %s.", actuator)
 
 
