@@ -75,7 +75,8 @@ class FlexibilityModel(ForecastModel):
         for schedule_id in range(num_schedules):
             schedule = self._generate_schedule(
                 pd.DataFrame(
-                    columns=["target", self._pname, self._qname], index=index
+                    columns=["target", self._pname, self._qname],
+                    index=index,
                 )
             )
 
