@@ -58,6 +58,8 @@ class Inverter(QGenerator):
 
         self._check_inputs()
 
+        next_state._inductive = self.inputs._inductive
+
         if self.config.q_control == QControl.P_SET:
             self._calc_p_set(next_state)
 
@@ -73,7 +75,7 @@ class Inverter(QGenerator):
         elif self.config.q_control == QControl.QP_SET:
             self._calc_qp_set(next_state)
 
-        if self.config.inverter_mode == "inductive":
+        if next_state.inductive:
             next_state.q_kvar *= -1
 
         self.state = next_state
@@ -89,6 +91,9 @@ class Inverter(QGenerator):
         if self.inputs.cos_phi_set is None:
             self.inputs.cos_phi_set = self.config.cos_phi
 
+        if self.inputs._inductive is None:
+            self.inputs._inductive = self.config.inverter_mode == "inductive"
+
     def _calc_p_set(self, next_state):
 
         # Current active power
